.. _regularizers:

Regularizers
============

.. autoclass:: mumott.optimization.regularizers.Laplacian
   :members:
   :inherited-members:

.. autoclass:: mumott.optimization.regularizers.TotalVariation
   :members:
   :inherited-members:

.. autoclass:: mumott.optimization.regularizers.L1Norm
   :members:
   :inherited-members:

.. autoclass:: mumott.optimization.regularizers.L2Norm
   :members:
   :inherited-members:

.. autoclass:: mumott.optimization.regularizers.HuberNorm
   :members:
   :inherited-members:
